@@ -28,12 +28,6 @@ class UserManagementResponseEmpty(OTRSClientException):
         super(OTRSClientException, self).__init__(message)
 
 
-class CustomerMailMissing(OTRSClientException):
-    def __init__(self, order_id):
-        message = "Customer without mail in order ID {}".format(order_id)
-        super(OTRSClientException, self).__init__(message)
-
-
 class ServiceTypeNotAllowedError(OTRSClientException):
     def __init__(self, id, service_type):
         message = "Contract {} with service type not allowed: {}".format(id, service_type)
