@@ -2,11 +2,11 @@ class FiberData:
     type = 'fiber'
 
     def __init__(
-        self, order_id, phone_number, iban, email, service_address, service_city,
-        service_zip, service_subdivision, service_subdivision_code, shipment_address, shipment_city, shipment_zip,
-        shipment_subdivision, previous_service, previous_provider, previous_internal_provider, product,
-        previous_owner_vat, previous_owner_name, previous_owner_surname, notes, old_contract_pon,
-            old_contract_fiber_speed, adsl_coverage, mm_fiber_coverage, vdf_fiber_coverage, change_address):
+            self, order_id, phone_number, iban, email, service_address, service_city,
+            service_zip, service_subdivision, service_subdivision_code, shipment_address, shipment_city, shipment_zip,
+            shipment_subdivision, previous_service, previous_provider, previous_internal_provider, product,
+            previous_owner_vat, previous_owner_name, previous_owner_surname, notes, adsl_coverage, mm_fiber_coverage,
+            vdf_fiber_coverage, change_address, old_contract_pon="", old_contract_fiber_speed=""):
 
         # Common to all Tickets
         self.order_id = order_id
