@@ -4,7 +4,7 @@ class MobileData:
     def __init__(
         self, order_id, phone_number, iban, email, sc_icc, icc,
         portability, previous_owner_vat, previous_owner_name,
-        previous_owner_surname, previous_provider, product, notes
+        previous_owner_surname, previous_provider, product, notes=""
     ):
         self.order_id = order_id
         self.phone_number = phone_number
