@@ -31,13 +31,16 @@ class ProvisionTicket():
             "State": self._ticket_state(),
             "Priority": self._ticket_priority(),
             "CustomerUser": self._customer_id(),
-            "CustomerID": self._customer_id()
+            "CustomerID": self._customer_id(),
+            "Service": self._ticket_service(),
+            "SLA": self._ticket_SLA(),
         })
 
     def _build_article(self):
         provision_article = ProvisionArticle(
             self.service_type(),
-            self.service_data.order_id
+            self.service_data.order_id,
+            self.service_data.notes,
         )
         return provision_article.call()
 
@@ -59,5 +62,17 @@ class ProvisionTicket():
     def _ticket_process_id(self):
         return self.otrs_configuration.process_id
 
+    def _ticket_service(self):
+        if hasattr(self.otrs_configuration, "service"):
+            return self.otrs_configuration.service
+        else:
+            return False
+
+    def _ticket_SLA(self):
+        if hasattr(self.otrs_configuration, "SLA"):
+            return self.otrs_configuration.SLA
+        else:
+            return False
+
     def _customer_id(self):
         return self.customer_data.id
