@@ -15,6 +15,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'order_id',
             'type',
             'iban',
+            'email',
             'phone_number',
             'sc_icc',
             'icc',
@@ -24,13 +25,13 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'previous_owner_surname',
             'previous_owner_vat',
             'product',
+            'notes',
         ])
         customer_data = Mock(spec=[
             'id',
             'first_name',
             'name',
             'vat_number',
-            'email',
             'phone',
             'street',
             'city',
@@ -61,6 +62,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'order_id',
             'type',
             'iban',
+            'email',
             'phone_number',
             'previous_provider',
             'previous_owner_name',
@@ -85,7 +87,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'product',
             'previous_internal_provider',
         ])
-        customer_data = Mock(spec=['id', 'first_name', 'name', 'vat_number', 'email', 'phone'])
+        customer_data = Mock(spec=['id', 'first_name', 'name', 'vat_number', 'phone'])
 
         service_data.type = 'adsl'
 
@@ -110,8 +112,11 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
     def test_create_fiber_ticket_factory(self, MockOTRSClient):
         service_data = Mock(spec=[
             'order_id',
+            'old_contract_pon',
+            'old_contract_fiber_speed',
             'type',
             'iban',
+            'email',
             'phone_number',
             'previous_provider',
             'previous_owner_name',
@@ -135,7 +140,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'product',
             'previous_internal_provider',
         ])
-        customer_data = Mock(spec=['id', 'first_name', 'name', 'vat_number', 'email', 'phone'])
+        customer_data = Mock(spec=['id', 'first_name', 'name', 'vat_number', 'phone'])
 
         service_data.type = 'fiber'
 
