@@ -18,6 +18,8 @@ class ADSLTicketTestCase(unittest.TestCase):
             "Type": ADSLTicketConfiguration.type,
             "Queue": ADSLTicketConfiguration.queue,
             "State": ADSLTicketConfiguration.state,
+            "SLA": False,
+            "Service": False,
             "Priority": ADSLTicketConfiguration.priority,
             "CustomerUser": customer_data.id,
             "CustomerID": customer_data.id
@@ -29,13 +31,17 @@ class ADSLTicketTestCase(unittest.TestCase):
     @patch('otrs_somconnexio.otrs_models.provision_ticket.ProvisionArticle')
     def test_build_article(self, MockInternetArticle):
         customer_data = Mock(spec=[])
-        service_data = Mock(spec=['order_id'])
+        service_data = Mock(spec=['order_id', 'notes'])
 
         mock_mobile_article = MockInternetArticle.return_value
 
         ADSLTicket(service_data, customer_data)._build_article()
 
-        MockInternetArticle.assert_called_with('adsl', service_data.order_id)
+        MockInternetArticle.assert_called_with(
+            'adsl', 
+            service_data.order_id, 
+            service_data.notes
+        )
         mock_mobile_article.call.assert_called_once()
 
     @patch('otrs_somconnexio.otrs_models.adsl_ticket.ADSLDynamicFields')
@@ -59,7 +65,6 @@ class ADSLTicketTestCase(unittest.TestCase):
     def test_create(self, MockOTRSClient):
         customer_data = Mock(spec=[
             'id',
-            'email',
             'phone',
             'first_name',
             'name',
@@ -68,6 +73,7 @@ class ADSLTicketTestCase(unittest.TestCase):
         service_data = Mock(spec=[
             'order_id',
             'iban',
+            'email',
             'previous_service',
             'phone_number',
             'previous_provider',
