@@ -23,11 +23,13 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             'name',
             'vat_number',
             'phone',
-            'email',
         ])
         self.service_data = Mock(spec=[
             'order_id',
+            'old_contract_pon',
+            'old_contract_fiber_speed',
             'iban',
+            'email',
             'phone_number',
             'service_address',
             'service_city',
@@ -66,6 +68,34 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["ProcessManagementProcessID"], "ADSLProcessID")
 
+    def test_pon_field(self):
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(
+            dynamic_fields_dct["ponAntic"],
+            self.service_data.old_contract_pon
+        )
+
+    def test_old_contract_fiber_speed_field(self):
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(
+            dynamic_fields_dct["velocitatSollicitadaContracteAnteriorCU"],
+            self.service_data.old_contract_fiber_speed
+        )
+
     def test_activity_id_field(self):
         dynamic_fields = FiberDynamicFields(
             self.service_data,
@@ -155,7 +185,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["telefonContacte"], "666666666")
 
     def test_contact_email_field(self):
-        self.customer_data.email = "test@email.org"
+        self.service_data.email = "test@email.org"
 
         dynamic_fields = FiberDynamicFields(
             self.service_data,
@@ -363,19 +393,6 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["cognom1Titular"], "Surname")
 
-    def test_notes_field(self):
-        self.service_data.notes = "Note"
-
-        dynamic_fields = FiberDynamicFields(
-            self.service_data,
-            self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["notes"], "Note")
-
     def test_adsl_coverage_field(self):
         self.service_data.adsl_coverage = "20"
 
