@@ -21,7 +21,6 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         self.customer_data = Mock(spec=[
             'id',
             'vat_number',
-            'email',
             'phone',
             'name',
             'first_name',
@@ -34,6 +33,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             'order_id',
             'phone_number',
             'iban',
+            'email',
             'sc_icc',
             'icc',
             'service_internet_unlimited',
@@ -189,7 +189,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["IBAN"], "ES6621000418401234567891")
 
     def test_contact_email_field(self):
-        self.customer_data.email = "test@email.org"
+        self.mobile_data.email = "test@email.org"
 
         dynamic_fields = MobileDynamicFields(
             self.mobile_data,
