@@ -15,17 +15,15 @@ class MobileTicketTestCase(unittest.TestCase):
         ])
         mobile_data.order_id = 123
 
-        customer_data = Mock(spec=[
-            'id',
-            'email',
-        ])
-        customer_data.email = 'contact@mail.com'
+        customer_data = Mock(spec=['id'])
 
         expected_ticket_arguments = {
             "Title": "Sol·licitud mobile {}".format(mobile_data.order_id),
             "Type": MobileTicketConfiguration.type,
             "Queue": MobileTicketConfiguration.queue,
             "State": MobileTicketConfiguration.state,
+            "SLA": False,
+            "Service": False,
             "Priority": MobileTicketConfiguration.priority,
             "CustomerUser": customer_data.id,
             "CustomerID": customer_data.id,
@@ -37,8 +35,9 @@ class MobileTicketTestCase(unittest.TestCase):
 
     @patch('otrs_somconnexio.otrs_models.provision_ticket.ProvisionArticle')
     def test_build_article(self, MockProvisionArticle):
-        mobile_data = Mock(spec=['order_id'])
+        mobile_data = Mock(spec=['order_id', 'notes'])
         mobile_data.order_id = 123
+        mobile_data.notes = "Hola mundo"
 
         customer_data = Mock(spec=['order_id'])
 
@@ -46,7 +45,11 @@ class MobileTicketTestCase(unittest.TestCase):
 
         MobileTicket(mobile_data, customer_data)._build_article()
 
-        MockProvisionArticle.assert_called_with('mobile', 123)
+        MockProvisionArticle.assert_called_with(
+            'mobile', 
+            mobile_data.order_id, 
+            mobile_data.notes
+        )
         mock_mobile_article.call.assert_called_once()
 
     @patch('otrs_somconnexio.otrs_models.mobile_ticket.MobileDynamicFields')
@@ -71,6 +74,7 @@ class MobileTicketTestCase(unittest.TestCase):
         mobile_data = Mock(spec=[
             'order_id',
             'iban',
+            'email',
             'phone_number',
             'sc_icc',
             'icc',
@@ -80,13 +84,13 @@ class MobileTicketTestCase(unittest.TestCase):
             'previous_owner_name',
             'previous_owner_surname',
             'product',
+            'notes',
         ])
         mobile_data.order_id = 4321
         mobile_data.portability = False
 
         customer_data = Mock(spec=[
             'id',
-            'email',
             'phone',
             'first_name',
             'name',
@@ -97,7 +101,6 @@ class MobileTicketTestCase(unittest.TestCase):
             'subdivision',
         ])
         customer_data.id = 1234
-        customer_data.email = 'contact@mail.coop'
 
         mock_otrs_client = Mock(spec=['create_otrs_process_ticket'])
         mock_otrs_client.create_otrs_process_ticket.return_value = Mock(MobileTicket, autospec=True)
